==> haskell-network-ip-0.3.0.2-87-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-ip
version: 0.3.0.2
id: network-ip-0.3.0.2-DBKKU8pOFEwEHZ96WxRbc3
key: network-ip-0.3.0.2-DBKKU8pOFEwEHZ96WxRbc3
license: BSD-3-Clause
copyright: 2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/network-ip
synopsis: Internet Protocol data structures
description:
    This package provides Internet Protocol data structures
category: Network
abi: 0c7a2d679730f667192a2d02736d4270
exposed: True
exposed-modules:
    Network.IP.Addr
import-dirs: /usr/lib/ghc-8.6.5/site-local/network-ip-0.3.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/network-ip-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/network-ip-0.3.0.2
hs-libraries: HSnetwork-ip-0.3.0.2-DBKKU8pOFEwEHZ96WxRbc3
depends:
    base-4.12.0.0 data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    data-dword-0.3.1.2-IecX8ZMFNUI96BJXkkV54h
    data-endian-0.1.1-8eI15msEBjH5vqdbWN68zz
    data-serializer-0.3.4-AUEYkloSVp7G7HdJ22jaj0
    data-textual-0.3.0.2-9Z40OQRxcFeICqtNaEyhFQ
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    parsers-0.12.10-ILAIFpn5o9X9YgFPnkWytu
    text-printer-0.5-7FHeqcLtqQ36mC3re1zjRL
    type-hint-0.1-HP8tKFGSWNP9WW8dks9Xp0
haddock-interfaces: /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html: /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-ip-0.3.0.2-88-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-ip
version: 0.3.0.2
id: network-ip-0.3.0.2-EtIWHccXwrdeMAyDTJmCC
key: network-ip-0.3.0.2-EtIWHccXwrdeMAyDTJmCC
license: BSD-3-Clause
copyright: 2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/network-ip
synopsis: Internet Protocol data structures
description:
    This package provides Internet Protocol data structures
category: Network
abi: 6d8a104c9ba403335feda82055c1c3de
exposed: True
exposed-modules:
    Network.IP.Addr
import-dirs: /usr/lib/ghc-8.6.5/site-local/network-ip-0.3.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/network-ip-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/network-ip-0.3.0.2
hs-libraries: HSnetwork-ip-0.3.0.2-EtIWHccXwrdeMAyDTJmCC
depends:
    base-4.12.0.0 data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    data-dword-0.3.1.2-8IdYE2sqRpA3VHeSCifUH7
    data-endian-0.1.1-8eI15msEBjH5vqdbWN68zz
    data-serializer-0.3.4-D0fyGHLtI3gAq0C2qPrjQW
    data-textual-0.3.0.2-GA5ftJvlGiz8K0ll8zYCLR
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    parsers-0.12.10-CLlrFboS2fBCFFrDdFWvFY
    text-printer-0.5-7FHeqcLtqQ36mC3re1zjRL
    type-hint-0.1-HP8tKFGSWNP9WW8dks9Xp0
haddock-interfaces: /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html: /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
